# Generated by Django 2.2.6 on 2020-03-18 19:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('courseaffils', '0004_auto_20170623_1231'),
    ]

    operations = [
        migrations.AlterField(
            model_name='coursedetails',
            name='name',
            field=models.CharField(help_text="type of data. Useful ones are 'instructor', 'semester', 'url', 'campus', 'times', 'call_number'", max_length=64),
        ),
        migrations.AlterField(
            model_name='coursedetails',
            name='value',
            field=models.CharField(help_text="The name's value for the course.", max_length=1024),
        ),
        migrations.AlterField(
            model_name='courseinfo',
            name='days',
            field=models.CharField(blank=True, help_text='e.g. "MTWRF"', max_length=7, null=True),
        ),
        migrations.AlterField(
            model_name='courseinfo',
            name='term',
            field=models.IntegerField(blank=True, choices=[(1, 'Spring'), (2, 'Summer'), (3, 'Fall')], null=True),
        ),
        migrations.AlterField(
            model_name='coursesettings',
            name='custom_headers',
            field=models.TextField(blank=True, help_text='Replaces main.css link in header.  You need to add this as full HTML (&lt;link rel="stylesheet" href="...." />) but the advantage is you can add custom javascript here, too.', null=True),
        ),
    ]
